@@ -133,7 +133,9 @@ impl Panel {
         con: &AppContext,
     ) -> Result<Command, ProgramError> {
         let sel_info = self.states[self.states.len() - 1].sel_info(app_state);
-        self.input.on_event(w, event, con, sel_info, app_state, self.state().get_mode())
+        let mode = self.state().get_mode();
+        let panel_state_type = self.state().get_type();
+        self.input.on_event(w, event, con, sel_info, app_state, mode, panel_state_type)
     }
 
     pub fn push_state(&mut self, new_state: Box<dyn PanelState>) {
