@@ -77,7 +77,7 @@ impl PanelState for HelpState {
     fn with_new_options(
         &mut self,
         _screen: Screen,
-        change_options: &dyn Fn(&mut TreeOptions),
+        change_options: &dyn Fn(&mut TreeOptions) -> &'static str,
         _in_new_panel: bool, // TODO open a tree if true
         _con: &AppContext,
     ) -> CmdResult {
